import os, json

def eac1(): 
    
    with open(os.getenv('SCI_ENG_DIR') + '/Telescope-EAC1.json', 'r') as openfile:
        eac1 = json.load(openfile)
   
    return eac1 

def eac2(): 
    
    with open(os.getenv('SCI_ENG_DIR') + '/Telescope-EAC2.json', 'r') as openfile:
        eac2 = json.load(openfile)
   
    return eac2 

def eac3(): 
    
    with open(os.getenv('SCI_ENG_DIR') + '/Telescope-EAC3.json', 'r') as openfile:
        eac3 = json.load(openfile)
   
    return eac3 

def wfi(): 
    
    with open(os.getenv('SCI_ENG_DIR') + '/WFI.json', 'r') as openfile:
        wfi = json.load(openfile)
   
    return wfi 

def uvs(): 
    
    with open(os.getenv('SCI_ENG_DIR') + '/UVS.json', 'r') as openfile:
        uvs = json.load(openfile)
   
    return uvs 




from setuptools import setup

setup(name="hwo_sci_eng",
      version="0.1.6",
      description="HWO Science Engineering Interface", 
      author="Breann Sitarski, NASA/GSFC, Jason Tumlinson, STScI", 
      author_email=" ",
      license="CC",
      keywords=["simulation", "astronomy", "astrophysics"],
      url="https://github.com/HWO-GOMAP-Working-Groups/Sci-Eng-Interface", 
      packages=["hwo_sci_eng/obs_config", "hwo_sci_eng/json", "hwo_sci_eng/utils"], 
      package_data={'':['*.yaml', '*.json', 'json/*json', '*/*/*.yaml', '*/*.yaml']}, 
#                        'obs_config/CI/*yaml', 'obs_config/UVI/*yaml', 'obs_config/Tel/*yaml', 'obs_config/Detectors/*yaml', 'obs_config/HRI/*yaml', 
#                        'hwo_sci_eng/obs_config/*.yaml', 'hwo_sci_eng/obs_config/CI/*yaml', 'hwo_sci_eng/obs_config/Detectors/*yaml', 'hwo_sci_eng/obs_config/HRI/*yaml', 'hwo_sci_eng/obs_config/Tel/*yaml', 'hwo_sci_eng/obs_config/UVI/*yaml']}, 
      include_package_data=True,
      classifiers=[
          "Programming Language :: Python :: 3.12",
      ],
      install_requires=[
            "setuptools>=61.0", 
      ],
)



import os, yaml

def eac1(): 
    
    with open(os.getenv('SCI_ENG_DIR') + '/obs_config/Tel/EAC1.yaml', 'r') as f:
        eac1 = yaml.load(f, Loader=yaml.SafeLoader)
   
    return eac1 

def eac2(): 
    
    raise NotImplementedError

def eac3(): 
    
    raise NotImplementedError


def hri(): 
    
    with open(os.getenv('SCI_ENG_DIR') + '/obs_config/HRI/HRI.yaml', 'r') as f:
        hri = yaml.load(f, Loader=yaml.SafeLoader)
   
    return hri 

def uvi(): 

    with open(os.getenv('SCI_ENG_DIR') + '/obs_config/UVI/UVI.yaml', 'r') as f:
        uvi= yaml.load(f, Loader=yaml.SafeLoader)

    return uvi 

def ci(): 

    with open(os.getenv('SCI_ENG_DIR') + '/obs_config/CI/CI.yaml', 'r') as f:
        ci = yaml.load(f, Loader=yaml.SafeLoader)

    return ci 

